@@ -4,7 +4,7 @@
 <context>
     <name>FeatherPad::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="175"/>
+        <location filename="../../about.ui" line="177"/>
         <source>License</source>
         <translation>Licence</translation>
     </message>
@@ -595,8 +595,8 @@
     <message>
         <location filename="../../fp.ui" line="305"/>
         <location filename="../../fpwin.cpp" line="4151"/>
-        <location filename="../../replace.cpp" line="61"/>
-        <location filename="../../replace.cpp" line="112"/>
+        <location filename="../../replace.cpp" line="63"/>
+        <location filename="../../replace.cpp" line="114"/>
         <source>Replacement</source>
         <translation>Remplacement</translation>
     </message>
@@ -883,12 +883,12 @@
     <message>
         <location filename="../../fpwin.cpp" line="2749"/>
         <source>Huge column!</source>
-        <translation type="unfinished"></translation>
+        <translation>Colonne énorme !</translation>
     </message>
     <message>
         <location filename="../../fpwin.cpp" line="2750"/>
         <source>Columns with more than 1000 rows are not supported.</source>
-        <translation type="unfinished"></translation>
+        <translation>Les colonnes de plus de 1000 lignes ne sont pas prises en charge.</translation>
     </message>
     <message>
         <location filename="../../fpwin.cpp" line="2874"/>
@@ -1129,17 +1129,17 @@
         <translation>À propos de FeatherPad</translation>
     </message>
     <message>
-        <location filename="../../replace.cpp" line="277"/>
+        <location filename="../../replace.cpp" line="285"/>
         <source>No Replacement</source>
         <translation>Aucun remplacement</translation>
     </message>
     <message>
-        <location filename="../../replace.cpp" line="279"/>
+        <location filename="../../replace.cpp" line="287"/>
         <source>One Replacement</source>
         <translation>Un remplacement</translation>
     </message>
     <message numerus="yes">
-        <location filename="../../replace.cpp" line="281"/>
+        <location filename="../../replace.cpp" line="289"/>
         <source>%Ln Replacements</source>
         <translation>
             <numerusform>%Ln remplacement</numerusform>
@@ -1147,7 +1147,7 @@
         </translation>
     </message>
     <message>
-        <location filename="../../replace.cpp" line="285"/>
+        <location filename="../../replace.cpp" line="293"/>
         <source>The first 1000 replacements are highlighted.</source>
         <translation>Les 1000 premiers remplacements sont surlignés.</translation>
     </message>
