@@ -4,7 +4,7 @@
 <context>
     <name>FeatherPad::AboutDialog</name>
     <message>
-        <location filename="../../about.ui" line="175"/>
+        <location filename="../../about.ui" line="177"/>
         <source>License</source>
         <translation>라이선스</translation>
     </message>
@@ -590,8 +590,8 @@
     <message>
         <location filename="../../fp.ui" line="305"/>
         <location filename="../../fpwin.cpp" line="4151"/>
-        <location filename="../../replace.cpp" line="61"/>
-        <location filename="../../replace.cpp" line="112"/>
+        <location filename="../../replace.cpp" line="63"/>
+        <location filename="../../replace.cpp" line="114"/>
         <source>Replacement</source>
         <translation>바꾸기</translation>
     </message>
@@ -1129,26 +1129,26 @@
         <translation>FeatherPad 정보</translation>
     </message>
     <message>
-        <location filename="../../replace.cpp" line="277"/>
+        <location filename="../../replace.cpp" line="285"/>
         <source>No Replacement</source>
-        <translation>교체 없음</translation>
+        <translation>바꾸기 없음</translation>
     </message>
     <message>
-        <location filename="../../replace.cpp" line="279"/>
+        <location filename="../../replace.cpp" line="287"/>
         <source>One Replacement</source>
-        <translation>한번 교체</translation>
+        <translation>한번 바꾸기</translation>
     </message>
     <message numerus="yes">
-        <location filename="../../replace.cpp" line="281"/>
+        <location filename="../../replace.cpp" line="289"/>
         <source>%Ln Replacements</source>
         <translation>
-            <numerusform>%Ln회 교체</numerusform>
+            <numerusform>%Ln회 바꾸기</numerusform>
         </translation>
     </message>
     <message>
-        <location filename="../../replace.cpp" line="285"/>
+        <location filename="../../replace.cpp" line="293"/>
         <source>The first 1000 replacements are highlighted.</source>
-        <translation>처음 1000개의 교체가 강조표시됩니다.</translation>
+        <translation>처음 1000개의 바꾸기가 강조표시됩니다.</translation>
     </message>
     <message>
         <location filename="../../syntax.cpp" line="314"/>
@@ -2331,7 +2331,7 @@ windows will be included in the saved session.</source>
     <message>
         <location filename="../../spellDialog.ui" line="62"/>
         <source>Replace with:</source>
-        <translation>대체할 단어:</translation>
+        <translation>교체할 단어:</translation>
     </message>
     <message>
         <location filename="../../spellDialog.ui" line="129"/>
